==> zio-aws-apigatewayv2_2.12-5.17.116.2-sources.jar: zio/aws/apigatewayv2/model/DeleteRouteResponseRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteRouteResponseRequest(
    apiId: __string,
    routeId: __string,
    routeResponseId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest = {
    import DeleteRouteResponseRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .routeId(__string.unwrap(routeId): java.lang.String)
      .routeResponseId(__string.unwrap(routeResponseId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.DeleteRouteResponseRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteRouteResponseRequest.wrap(buildAwsValue())
}
object DeleteRouteResponseRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteRouteResponseRequest =
      zio.aws.apigatewayv2.model
        .DeleteRouteResponseRequest(apiId, routeId, routeResponseId)
    def apiId: __string
    def routeId: __string
    def routeResponseId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getRouteId: ZIO[Any, Nothing, __string] = ZIO.succeed(routeId)
    def getRouteResponseId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(routeResponseId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest
  ) extends zio.aws.apigatewayv2.model.DeleteRouteResponseRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val routeId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.routeId())
    override val routeResponseId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.routeResponseId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest
  ): zio.aws.apigatewayv2.model.DeleteRouteResponseRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.12-7.21.15.7-sources.jar: zio/aws/apigatewayv2/model/DeleteRouteResponseRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteRouteResponseRequest(
    apiId: __string,
    routeId: __string,
    routeResponseId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest = {
    import DeleteRouteResponseRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .routeId(routeId: java.lang.String)
      .routeResponseId(routeResponseId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.DeleteRouteResponseRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteRouteResponseRequest.wrap(buildAwsValue())
}
object DeleteRouteResponseRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteRouteResponseRequest =
      zio.aws.apigatewayv2.model
        .DeleteRouteResponseRequest(apiId, routeId, routeResponseId)
    def apiId: __string
    def routeId: __string
    def routeResponseId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getRouteId: ZIO[Any, Nothing, __string] = ZIO.succeed(routeId)
    def getRouteResponseId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(routeResponseId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest
  ) extends zio.aws.apigatewayv2.model.DeleteRouteResponseRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val routeId: __string = impl.routeId(): __string
    override val routeResponseId: __string = impl.routeResponseId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteResponseRequest
  ): zio.aws.apigatewayv2.model.DeleteRouteResponseRequest.ReadOnly =
    new Wrapper(impl)
}
